@@ -26,22 +26,35 @@ class AutoDocumentEncoder(DocumentEncoder):
         self.device = device
         self.model = AutoModel.from_pretrained(model_name)
         self.model.to(self.device)
-        self.tokenizer = AutoTokenizer.from_pretrained(tokenizer_name or model_name)
+        try:
+            self.tokenizer = AutoTokenizer.from_pretrained(tokenizer_name or model_name)
+        except:
+            self.tokenizer = AutoTokenizer.from_pretrained(tokenizer_name or model_name, use_fast=False)
         self.has_model = True
         self.pooling = pooling
         self.l2_norm = l2_norm
 
-    def encode(self, texts, titles=None, **kwargs):
-        if titles:
-            texts = [f'{title} {text}' for title, text in zip(titles, texts)]
-        inputs = self.tokenizer(
-            texts,
-            max_length=512,
-            padding='longest',
+    def encode(self, texts, titles=None, max_length=256, add_sep=False, **kwargs):
+        shared_tokenizer_kwargs = dict(
+            max_length=max_length,
             truncation=True,
+            padding='longest',
+            return_attention_mask=True,
+            return_token_type_ids=False,
+            return_tensors='pt',
             add_special_tokens=True,
-            return_tensors='pt'
         )
+        input_kwargs = {}
+        if not add_sep:
+            input_kwargs["text"] = [f'{title} {text}' for title, text in zip(titles, texts)] if titles is not None else texts
+        else:
+            if titles is not None:
+                input_kwargs["text"] = titles
+                input_kwargs["text_pair"] = texts
+            else:
+                input_kwargs["text"] = texts
+
+        inputs = self.tokenizer(**input_kwargs, **shared_tokenizer_kwargs)
         inputs.to(self.device)
         outputs = self.model(**inputs)
         if self.pooling == "mean":
@@ -69,10 +82,11 @@ class AutoQueryEncoder(QueryEncoder):
             query = f'{self.prefix} {query}'
         inputs = self.tokenizer(
             query,
-            padding='longest',
-            truncation=True,
             add_special_tokens=True,
-            return_tensors='pt'
+            return_tensors='pt',
+            truncation='only_first',
+            padding='longest',
+            return_token_type_ids=False,
         )
         inputs.to(self.device)
         outputs = self.model(**inputs)[0].detach().cpu().numpy()
