@@ -87,6 +87,8 @@ def define_search_args(parser):
     parser.add_argument('--b', type=float, help='BM25 b parameter.')
 
     parser.add_argument('--rm3', action='store_true', help="Use RM3")
+    parser.add_argument('--rocchio', action='store_true', help="Use Rocchio")
+    parser.add_argument('--rocchio-use-negative', action='store_true', help="Use nonrelevant labels in Rocchio")
     parser.add_argument('--qld', action='store_true', help="Use QLD")
 
     parser.add_argument('--language', type=str, help='language code for BM25, e.g. zh for Chinese', default='en')
@@ -178,6 +180,13 @@ if __name__ == "__main__":
     if args.rm3:
         search_rankers.append('rm3')
         searcher.set_rm3()
+    
+    if args.rocchio:
+        search_rankers.append('rocchio')
+        if args.rocchio_use_negative:
+            searcher.set_rocchio(gamma=0.15, use_negative=True)
+        else:
+            searcher.set_rocchio()
 
     fields = dict()
     if args.fields:
