@@ -116,6 +116,32 @@ class TestSearch(unittest.TestCase):
         self.assertEqual(results['q2'][9].docid, 'CACM-3040')
         self.assertAlmostEqual(results['q2'][9].score, 2.68780, places=5)
 
+    def test_batch_rocchio(self):
+        self.searcher.set_rocchio()
+        results = self.searcher.batch_search(['information retrieval', 'search'], ['q1', 'q2'], threads=2)
+        self.searcher.unset_rocchio()
+
+        self.assertEqual(3204, self.searcher.num_docs)
+        self.assertTrue(isinstance(results, Dict))
+
+        self.assertTrue(isinstance(results['q1'], List))
+        self.assertTrue(isinstance(results['q1'][0], JLuceneSearcherResult))
+        self.assertEqual(results['q1'][0].docid, 'CACM-3134')
+        self.assertAlmostEqual(results['q1'][0].score, 7.18830, places=5)
+
+        self.assertTrue(isinstance(results['q1'][9], JLuceneSearcherResult))
+        self.assertEqual(results['q1'][9].docid, 'CACM-2140')
+        self.assertAlmostEqual(results['q1'][9].score, 5.57970, places=5)
+
+        self.assertTrue(isinstance(results['q2'], List))
+        self.assertTrue(isinstance(results['q2'][0], JLuceneSearcherResult))
+        self.assertEqual(results['q2'][0].docid, 'CACM-3041')
+        self.assertAlmostEqual(results['q2'][0].score, 6.14870, places=5)
+
+        self.assertTrue(isinstance(results['q2'][9], JLuceneSearcherResult))
+        self.assertEqual(results['q2'][9].docid, 'CACM-2251')
+        self.assertAlmostEqual(results['q2'][9].score, 4.97380, places=5)
+
     def test_basic_k(self):
         hits = self.searcher.search('information retrieval', k=100)
 
@@ -216,8 +242,13 @@ class TestSearch(unittest.TestCase):
         self.assertEqual(hits[9].docid, 'CACM-2516')
         self.assertAlmostEqual(hits[9].score, 1.70180, places=5)
 
+        feedback_terms = self.searcher.get_feedback_terms('information retrieval')
+        self.assertEqual(len(feedback_terms), 10)
+        self.assertAlmostEqual(feedback_terms['storag'], 0.024701, places=5)
+
         self.searcher.unset_rm3()
         self.assertFalse(self.searcher.is_using_rm3())
+        self.assertIsNone(self.searcher.get_feedback_terms('information retrieval'))
 
         hits = self.searcher.search('information retrieval')
 
@@ -251,8 +282,13 @@ class TestSearch(unittest.TestCase):
         self.assertEqual(hits[9].docid, 'CACM-2140')
         self.assertAlmostEqual(hits[9].score, 5.57970, places=5)
 
+        feedback_terms = self.searcher.get_feedback_terms('information retrieval')
+        self.assertEqual(len(feedback_terms), 10)
+        self.assertAlmostEqual(feedback_terms['storag'], 0.132200, places=5)
+
         self.searcher.unset_rocchio()
         self.assertFalse(self.searcher.is_using_rocchio())
+        self.assertIsNone(self.searcher.get_feedback_terms('information retrieval'))
 
         hits = self.searcher.search('information retrieval')
 
@@ -263,7 +299,7 @@ class TestSearch(unittest.TestCase):
 
         self.searcher.set_rocchio(top_fb_terms=10, top_fb_docs=8, bottom_fb_terms=10,
                                   bottom_fb_docs=8, alpha=0.4, beta=0.5, gamma=0.1,
-                                  output_query=False, use_negative=True)
+                                  debug=False, use_negative=True)
         self.assertTrue(self.searcher.is_using_rocchio())
 
         hits = self.searcher.search('information retrieval')
@@ -275,7 +311,7 @@ class TestSearch(unittest.TestCase):
 
         self.searcher.set_rocchio(top_fb_terms=10, top_fb_docs=8, bottom_fb_terms=10,
                                   bottom_fb_docs=8, alpha=0.4, beta=0.5, gamma=0.1,
-                                  output_query=False, use_negative=False)
+                                  debug=False, use_negative=False)
         self.assertTrue(self.searcher.is_using_rocchio())
 
         hits = self.searcher.search('information retrieval')
